package App::DetectPericmdScript;

our $DATE = '2015-07-30'; # DATE
our $VERSION = '0.01'; # VERSION

1;
# ABSTRACT: Detect Perinci::CmdLine script (CLI)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::DetectPericmdScript - Detect Perinci::CmdLine script (CLI)

=head1 VERSION

This document describes version 0.01 of App::DetectPericmdScript (from Perl distribution App-DetectPericmdScript), released on 2015-07-30.

=head1 SEE ALSO

See L<detect-pericmd-script>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-DetectPericmdScript>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-DetectPericmdScript>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-DetectPericmdScript>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
